@@ -1,9 +1,10 @@
 var fs = require('fs'), 
 	parser = require('./parser'),
 	Ascii = require('./ascii'),
+	Binary = require('./binary'),
 	package = JSON.parse( fs.readFileSync("../package.json", "utf-8") ), 
 	utils = require('./utils'),
-THREE = require('three');
+    THREE = require('three');
 
 // default options
 var defaults = require('./options');
@@ -14,7 +15,7 @@ Main = function ( options ) {
 	// set default options
 	this.options = defaults;
 	// extend default options
-	// this.options = Object.extend(this.options, options)
+	this.options = utils.extend( this.options, options );
 	// add info from package.json
 	this.options.package = package;
 	this.options.files = [];
@@ -69,28 +70,63 @@ Main.prototype = {
 			
 	}, 
 	
+    //Convert infile.obj to outfile.js + outfile.bin
+    minify: function ( source, destination, callback ) {
+        //
+        if( !fs.existsSync(source) ) return console.log("Couldn't find "+ source);
+		//
+        var self = this;
+		//set type to ascii
+		this.set({ type : "binary" });
+		// load the OBJ file
+		self.load( source, function( data ){
+			// validate data?
+			self.output( data, destination, function(){
+				//
+				if ( callback ) callback( data );
+				
+			});
+		});
+			
+	}, 
+	
 	// convert data to binary file
 	compress: function ( json ) {
-		
+        
+		var self = this;
+		//set type to ascii
+		this.set({ type : "binary" });
+		// load the OBJ file
+		self.load( source, function( data ){
+			// validate data?
+			self.output( data, destination, function(){
+				//
+				if ( callback ) callback( data );
+				
+			});
+		});
+			
 	}, 
 	
 	output: function( data, destination, callback ){
 		var json, output = {};
+        // 
 		switch( this.options.type ){
 			case "ascii":
 				var ascii = new Ascii( this.options );
-				json = ascii.compile( data );
+				output = ascii.compile( data );
+                // save json to file
+                ascii.save( destination, output, callback );
 			break;
 			case "binary":
-				// TBA
+                // add binary file in the options
+                this.set({ buffers : utils.get_name(destination) +".bin" });
+				var binary = new Binary( this.options );
+				output = binary.compile( data );
+                binary.save( destination, output, callback );
 			break;
 		};
-		// save to file
-		fs.writeFile(destination, JSON.stringify( json ), function(err){
-			if( err ) return console.log( err );
-			// return to callback
-			if ( callback ) callback( json );
-		});
+		
 	}
 	
 };
